@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2010 Dirk Holtwick, holtwick.it
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +12,30 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import xhtml2pdf.pisa as pisa
-from six import StringIO
-
 import logging
+from abc import abstractmethod
+from io import StringIO
+
+from xhtml2pdf import pisa
+
+log = logging.getLogger(__name__)
 
 
-log = logging.getLogger("xhtml2pdf.wsgi")
-
-
-class Filter(object):
-    def __init__(self, app):
+class Filter:
+    def __init__(self, app) -> None:
         self.app = app
 
     def __call__(self, environ, start_response):
-        script_name = environ.get('SCRIPT_NAME', '')
-        path_info = environ.get('PATH_INFO', '')
+        script_name = environ.get("SCRIPT_NAME", "")
+        path_info = environ.get("PATH_INFO", "")
         sent = []
-        written_response = StringIO.StringIO()
+        written_response = StringIO()
 
         def replacement_start_response(status, headers, exc_info=None):
             if not self.should_filter(status, headers):
                 return start_response(status, headers, exc_info)
-            else:
-                sent[:] = [status, headers, exc_info]
-                return written_response.write
+            sent[:] = [status, headers, exc_info]
+            return written_response.write
 
         app_iter = self.app(environ, replacement_start_response)
         if not sent:
@@ -48,40 +45,45 @@ class Filter(object):
             for chunk in app_iter:
                 written_response.write(chunk)
         finally:
-            if hasattr(app_iter, 'close'):
+            if hasattr(app_iter, "close"):
                 app_iter.close()
         body = written_response.getvalue()
         status, headers, body = self.filter(
-            script_name, path_info, environ, status, headers, body)
+            script_name, path_info, environ, status, headers, body
+        )
         start_response(status, headers, exc_info)
         return [body]
 
-    def should_filter(self, status, headers):
-        print (headers)
+    @staticmethod
+    def should_filter(_status, headers):
+        print(headers)
 
-    def filter(self, status, headers, body):
+    @abstractmethod
+    def filter(self, status, headers, body):  # noqa: A003
         raise NotImplementedError
 
 
 class HTMLFilter(Filter):
-    def should_filter(self, status, headers):
-        if not status.startswith('200'):
+    @staticmethod
+    def should_filter(status, headers):
+        if not status.startswith("200"):
             return False
         for name, value in headers:
-            if name.lower() == 'content-type':
-                return value.startswith('text/html')
+            if name.lower() == "content-type":
+                return value.startswith("text/html")
         return False
 
 
 class PisaMiddleware(HTMLFilter):
-    def filter(self, script_name, path_info, environ, status, headers, body):
+    @staticmethod
+    def filter(_script_name, _path_info, environ, status, headers, body):  # noqa: A003
         topdf = environ.get("pisa.topdf", "")
         if topdf:
-            dst = StringIO.StringIO()
+            dst = StringIO()
             pisa.CreatePDF(body, dst, show_error_as_pdf=True)
             headers = [
                 ("content-type", "application/pdf"),
-                ("content-disposition", "attachment; filename=" + topdf)
+                ("content-disposition", "attachment; filename=" + topdf),
             ]
             body = dst.getvalue()
         return status, headers, body
